@@ -18,9 +18,9 @@
 
 #include "KBlocksPlayManager.h"
 
-class KgThemeSelector;
-class KgThemeProvider;
-class KgTheme;
+class KGameThemeSelector;
+class KGameThemeProvider;
+class KGameTheme;
 class QLabel;
 class GameLogicInterface;
 class GraphicsInterface;
@@ -36,7 +36,7 @@ public:
         GameLogicInterface *p,
         GraphicsInterface *graphics,
         SoundInterface *sound,
-        KgThemeProvider *themeProvider,
+        KGameThemeProvider *themeProvider,
         KBlocksPlayManager *pM,
         int capacity,
         int gamecount
@@ -72,7 +72,7 @@ private Q_SLOTS:
     void onAllGamesStopped();
     void levelChanged();
     void setSoundsEnabled(bool enabled);
-    void onThemeChanged(const KgTheme *theme);
+    void onThemeChanged(const KGameTheme *theme);
 
 protected:
     void closeEvent(QCloseEvent *event) override;
@@ -95,7 +95,7 @@ private:
 
     KBlocksAIPlayer *mpAIPlayer = nullptr;
 
-    KgThemeSelector *m_themeSelector = nullptr;
+    KGameThemeSelector *m_themeSelector = nullptr;
     QAction *m_pauseAction = nullptr;
     QLabel *mScore = nullptr;
 };
